package com.github.wxiaoqi.security.admin.biz;

import com.alibaba.fastjson.JSONObject;
import com.github.wxiaoqi.security.admin.entity.AppUserAlipay;
import com.github.wxiaoqi.security.admin.entity.AppUserLogin;
import com.github.wxiaoqi.security.admin.entity.AppUserRelationTemp;
import com.github.wxiaoqi.security.admin.mapper.AppUserAlipayMapper;
import com.github.wxiaoqi.security.admin.mapper.AppUserRelationTempMapper;
import com.github.wxiaoqi.security.auth.client.config.UserAuthConfig;
import com.github.wxiaoqi.security.auth.client.jwt.UserAuthUtil;
import com.github.wxiaoqi.security.common.biz.BaseBiz;
import com.github.wxiaoqi.security.common.msg.ObjectRestResponse;
import com.github.wxiaoqi.security.common.util.process.ResultCode;
import com.xxfc.platform.universal.feign.ThirdFeign;
import com.xxfc.platform.vehicle.constant.ResCode.ResCode;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import tk.mybatis.mapper.entity.Example;

import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.List;

/**
 * 支付宝账号表
 *
 * @author libin
 * @email 18178966185@163.com
 * @date 2019-07-03 16:36:44
 */
@Service
@Slf4j
public class AppUserAlipayBiz extends BaseBiz<AppUserAlipayMapper, AppUserAlipay>{

    @Autowired
    private UserAuthUtil userAuthUtil;

    @Autowired
    private UserAuthConfig userAuthConfig;

    @Autowired
    AppUserLoginBiz appUserLoginBiz;
    @Autowired
    ThirdFeign thirdFeign;

    //添加支付宝账号
    public  void  addAlipay(Integer userId,String txAlipay){
        AppUserAlipay appUserAlipay=new AppUserAlipay();
        appUserAlipay.setTxAlipay(txAlipay);
        appUserAlipay.setUserId(userId);
        appUserAlipay.setIsDel(0);
        AppUserAlipay appUserAlipay1=selectOne(appUserAlipay);
        if (appUserAlipay1==null){
            appUserAlipay.setIsDefault(1);
            insertSelective(appUserAlipay);
        }else {
            appUserAlipay1.setIsDefault(1);
            updateSelectiveById(appUserAlipay1);
        }
    }
   //获取支付宝列表
    public List<AppUserAlipay> getListByUserId(Integer userId){
        Example example=new Example(AppUserAlipay.class);
        example.createCriteria().andEqualTo("userId",userId).andEqualTo("isDel",0);
        example.setOrderByClause("is_default desc");
        return  selectByExample(example);
    }

    /**
     * 支付宝授权获取用户信息
     * @param code
     * @return
     */
    public ObjectRestResponse getUserInfo(String code, HttpServletRequest request) {
        String username = null;
        AppUserAlipay appUserAlipay = new AppUserAlipay();
        try {
            username = userAuthUtil.getInfoFromToken(userAuthConfig.getToken(request)).getId();
            if (StringUtils.isBlank(username)) {
                return ObjectRestResponse.createFailedResult(ResultCode.RSTOKEN_EXPIRED_CODE, ResultCode.getMsg(ResultCode.RSTOKEN_EXPIRED_CODE));
            } else {
                appUserAlipay.setUserId(Integer.parseInt(username));
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        String result = thirdFeign.getAliPayUserInfo(code).getData();
        if (StringUtils.isNotBlank(result)) {
            JSONObject jsonObject = JSONObject.parseObject(result);
            if (jsonObject != null && jsonObject.getString("code").equals("10000")) {
                String account = jsonObject.getString("userId");
                if (account != null) {
                    appUserAlipay.setTxAlipay(account);
                    appUserAlipay.setCrtTime(new Date().getTime());
                    appUserAlipay.setIsDel(0);
                }
                String nickname = jsonObject.getString("nickName");
                if (nickname != null) {
                    appUserAlipay.setNickname(nickname);
                }
                log.info("用户支付宝信息： {}", appUserAlipay.toString());
                insertSelectiveRe(appUserAlipay);
                return ObjectRestResponse.succ();
            } else {
                return ObjectRestResponse.createFailedResult(Integer.parseInt(jsonObject.getString("code")), jsonObject.getString("sub_msg"));
            }
        }
        return ObjectRestResponse.createDefaultFail();
    }

}